@@ -2,7 +2,6 @@ use std::fs;
 use std::time::SystemTime;
 
 use bigdecimal::BigDecimal;
-use bigdecimal::num_bigint::BigInt;
 use chrono::{DateTime, Utc};
 
 use voltdb_client_rust::encode::*;
@@ -14,9 +13,9 @@ fn main() -> Result<(), VoltError> {
     #[derive(Debug)]
     struct Test {
         t1: Option<bool>,
-        t2: Option<i8>,
-        t3: Option<i16>,
-        t4: Option<i32>,
+        t2: Option<i16>,
+        t3: Option<i32>,
+        t4: Option<i64>,
         t5: Option<f64>,
         t6: Option<BigDecimal>,
         t7: Option<String>,
@@ -26,9 +25,9 @@ fn main() -> Result<(), VoltError> {
     impl From<&mut VoltTable> for Test {
         fn from(table: &mut VoltTable) -> Self {
             let t1 = table.get_bool_by_column("T1").unwrap();
-            let t2 = table.get_i8_by_column("t2").unwrap();
-            let t3 = table.get_i16_by_column("t3").unwrap();
-            let t4 = table.get_i32_by_column("t4").unwrap();
+            let t2 = table.get_i16_by_column("t2").unwrap();
+            let t3 = table.get_i32_by_column("t3").unwrap();
+            let t4 = table.get_i64_by_column("t4").unwrap();
             let t5 = table.get_f64_by_column("t5").unwrap();
             let t6 = table.get_decimal_by_column("t6").unwrap();
             let t7 = table.get_string_by_column("t7").unwrap();
@@ -74,6 +73,7 @@ fn main() -> Result<(), VoltError> {
 
     let insert = "insert into test_types (T1) values (NULL);";
     block_for_result(&node.query(insert)?)?;
+    block_for_result(&node.query("insert into test_types (T1,T2,T3,T4) values (1, 32767, 2147483647, 9223372036854775807 );")?)?;
     let mut table = block_for_result(&node.query("select * from test_types")?)?;
     while table.advance_row() {
         let test: Test = table.map_row();
@@ -81,6 +81,8 @@ fn main() -> Result<(), VoltError> {
     }
     let bs = vec![1 as u8, 2, 3, 4];
     let time = DateTime::from(SystemTime::now());
+
+
     // call proc with parameters
     let mut table = block_for_result(&node.call_sp("test_types.insert", volt_param![1,2,3,4,5,6,"7",bs,time])?)?;
     while table.advance_row() {
@@ -93,14 +95,20 @@ fn main() -> Result<(), VoltError> {
     assert!(table.has_error().is_none());
     // create sp
     let script = "CREATE PROCEDURE  FROM CLASS com.johnny.ApplicationCreate;";
-    block_for_result(&node.query(script)?);
+    let res = block_for_result(&node.query(script)?);
+    match res {
+        Ok(_) => {}
+        Err(err) => {
+            println!("{}", err)
+        }
+    };
     let header = vec!["T1", "T2", "T3", "T4", "T5", "T6", "T7", "T8", "T9"];
     let tp = vec![TINYINT_COLUMN, SHORT_COLUMN, INT_COLUMN, LONG_COLUMN, FLOAT_COLUMN, DECIMAL_COLUMN, STRING_COLUMN, VAR_BIN_COLUMN, TIMESTAMP_COLUMN];
     let header: Vec<String> = header.iter().map(|f| f.to_string()).collect::<Vec<String>>();
     let mut table = VoltTable::new_table(tp, header);
     let decimal = BigDecimal::from(16);
-    let data = volt_param! {true, 12 as i8 , 13 as i16,  14 as i32,  15.0, decimal  , "17",bs, time   };
-    table.add_row(data);
+    let data = volt_param! {true, 32767 as i16 , 2147483647 as i32,  9223372036854775807 as i64 ,  15.0, decimal  , "17",bs, time   };
+    table.add_row(data)?;
     // call proc with volt table
     let mut res = block_for_result(&node.call_sp("ApplicationCreate", volt_param![table])?)?;
     while res.advance_row() {
